@@ -1,11 +1,25 @@
+# This code is licensed under the New BSD License
+# 2009, Alexander Artemenko <svetlyak.40wt@gmail.com>
+# For other contacts, visit http://aartemenko.com
+
 import os
-from models import *
-from elixir import metadata, setup_all, create_all, session
-from sqlalchemy.sql import not_
+import sys
+
+try:
+    from elixir import metadata, setup_all, create_all, session
+    from models import *
+    from sqlalchemy.sql import not_
+except ImportError:
+    """Ignore this imports because they may fail
+       during __version__ import."""
+
 from utils import get_or_create, make_list
 from pdb import set_trace
 
-__version__ = '0.1.1'
+from exceptions import *
+
+__version__ = '0.1.2'
+__all__ = ['GTD']
 
 class GTD(object):
     def __init__(self, filename):
@@ -80,9 +94,17 @@ class GTD(object):
 
     def closeTask(self, task_id):
         task = self.getTaskById(task_id)
+        if task is None:
+            raise TaskNotFound
+
         task.done = True
         self.save(task)
 
+    def deleteTask(self, task_id):
+        task = self.getTaskById(task_id)
+        session.delete(task)
+        session.commit()
+
     def _createTags(self, tags):
         return [get_or_create(Tag, title = tag) for tag in tags]
 
